import QtQuick 1.1
import qb.components 1.0
import qb.base 1.0;

App {
	id: root
	// These are the URL's for the QML resources from which our widgets will be instantiated.
	// By making them a URL type property they will automatically be converted to full paths,
	// preventing problems when passing them around to code that comes from a different path.
	property url trayUrl : "DomoticzTray.qml";
	property url tileUrl : "DomoticzTile.qml"
	property url thumbnailIcon: "./drawables/DomoticzSystrayIcon.png"
	property url domoticzScreenUrl : "DomoticzScreen.qml"

	property string timeStr
	property string dateStr
	//Edit these settings:
	property string hostName: "192.168.1.192"
	property string portNum: "8080"
	//Stop editing here!

	property string switch1StatusIcon
	property string switch1StatusIconDim
	property string switch1Name
	property string switch1LastUpdate
	property string switch2StatusIcon
	property string switch2StatusIconDim
	property string switch2Name
	property string switch2LastUpdate
	


	function init() {
		registry.registerWidget("tile", tileUrl, this, null, {thumbLabel: qsTr("Domoticz"), thumbIcon: thumbnailIcon, thumbCategory: "general", thumbWeight: 30, baseTileWeight: 10, thumbIconVAlignment: "center"});
		registry.registerWidget("systrayIcon", trayUrl, this, "domoticzTray");
		registry.registerWidget("screen", domoticzScreenUrl, this);
	}

	function readDeviceStatus(idx) {
		var xmlhttp = new XMLHttpRequest();
		var i;
		var j;
		var tmpDeviceStatus;
		xmlhttp.onreadystatechange=function() {
			if (xmlhttp.readyState == 4) {
				if (xmlhttp.status == 200) {
					var res = xmlhttp.responseText;
					i = res.indexOf('"LastUpdate"');
					j = res.indexOf('"', i+16);
					if (idx == 1) {
						switch1LastUpdate = res.substring(i+16 , j);
					} else {
						switch2LastUpdate = res.substring(i+16 , j);
					}
					i = res.indexOf('"Name"');
					j = res.indexOf('"', i+10);
					if (idx == 1) {
						switch1Name = res.substring(i+10 , j);
					} else {
						switch2Name = res.substring(i+10 , j);
					}
					i = res.indexOf('"Status"', j);
					j = res.indexOf('"', i+12);
					tmpDeviceStatus = res.substring(i+12, j);
					if (idx == 1) {
						if (tmpDeviceStatus == "On") {
							switch1StatusIcon = "./drawables/LightBulbOn.png";
							switch1StatusIconDim = "./drawables/LightBulbOnDim.png";
						} else {
							switch1StatusIcon = "./drawables/LightBulbOff.png";
							switch1StatusIconDim = "./drawables/LightBulbOffDim.png";
						}
					} else {
						if (tmpDeviceStatus == "On") {
							switch2StatusIcon = "./drawables/LightBulbOn.png";
							switch2StatusIconDim = "./drawables/LightBulbOnDim.png";
						} else {
							switch2StatusIcon = "./drawables/LightBulbOff.png";
							switch2StatusIconDim = "./drawables/LightBulbOffDim.png";
						}
					}
				}
			}
		}
		xmlhttp.open("GET", "http://"+hostName+":"+portNum+"/json.htm?type=devices&rid="+idx, true);
		xmlhttp.send();
	}

	function updateDomoticzLight1() {
		readDeviceStatus(1);
	}

	function updateDomoticzLight2() {
		readDeviceStatus(2);
	}


	Timer {
		id: datetimeTimer
		interval: 30000
		triggeredOnStart: true
		running: true
		repeat: true
		onTriggered: {
			updateDomoticzLight1();
			updateDomoticzLight2();
		}
	}

}
